requirements_are_satisfied

Function requirements_are_satisfied 

pub async fn requirements_are_satisfied(
    conn: &mut PgConnection,
    user_context: &ChatbotTurnContext,
    requirements: &[ToolRequirement],
) -> ChatbotResult<bool>
Whether requirements all pass, for the callers that decide what to offer or whether to abort rather than gating a mutation.